@@ -1,3 +1,10 @@
+#!/bin/sh
+# Add KDE library directory to /etc/ld.so.conf:
+if fgrep /opt/kde/lib etc/ld.so.conf 1> /dev/null 2> /dev/null ; then
+  true
+else
+  echo "/opt/kde/lib" >> etc/ld.so.conf
+fi
 ( cd opt/kde/lib ; rm -rf libmcop.so )
 ( cd opt/kde/lib ; ln -sf libmcop.so.1.0.0 libmcop.so )
 ( cd opt/kde/lib ; rm -rf libartsdsp.so.0 )
